Module: Aws::FSx

Defined in:
lib/aws-sdk-fsx/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-fsx/plugins/endpoints.rb,
lib/aws-sdk-fsx/endpoint_provider.rb,
lib/aws-sdk-fsx/client_api.rb,
lib/aws-sdk-fsx/endpoints.rb,
lib/aws-sdk-fsx/resource.rb,
lib/aws-sdk-fsx/errors.rb,
lib/aws-sdk-fsx/client.rb,
lib/aws-sdk-fsx/types.rb,
lib/aws-sdk-fsx.rb

Overview

This module provides support for Amazon FSx. This module is available in the aws-sdk-fsx gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

f_sx = Aws::FSx::Client.new
resp = f_sx.associate_file_system_aliases(params)

See Client for more information.

Errors

Errors returned from Amazon FSx are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::FSx::Errors::ServiceError
  # rescues all Amazon FSx API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.137.0'