Class: Aws::FSx::Types::CopySnapshotAndUpdateVolumeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#administrative_actionsArray<Types::AdministrativeAction>

A list of administrative actions for the file system that are in process or waiting to be processed. Administrative actions describe changes to the Amazon FSx system.



1036
1037
1038
1039
1040
1041
1042
# File 'lib/aws-sdk-fsx/types.rb', line 1036

class CopySnapshotAndUpdateVolumeResponse < Struct.new(
  :volume_id,
  :lifecycle,
  :administrative_actions)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleString

The lifecycle state of the destination volume.



1036
1037
1038
1039
1040
1041
1042
# File 'lib/aws-sdk-fsx/types.rb', line 1036

class CopySnapshotAndUpdateVolumeResponse < Struct.new(
  :volume_id,
  :lifecycle,
  :administrative_actions)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume that you copied the snapshot to.



1036
1037
1038
1039
1040
1041
1042
# File 'lib/aws-sdk-fsx/types.rb', line 1036

class CopySnapshotAndUpdateVolumeResponse < Struct.new(
  :volume_id,
  :lifecycle,
  :administrative_actions)
  SENSITIVE = []
  include Aws::Structure
end