Class: Aws::FSx::Types::DataRepositoryTaskStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DataRepositoryTaskStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Provides the task status showing a running total of the total number of files to be processed, the number successfully processed, and the number of files the task failed to process.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_count ⇒ Integer
A running total of the number of files that the task failed to process.
-
#last_updated_time ⇒ Time
The time at which the task status was last updated.
-
#released_capacity ⇒ Integer
The total amount of data, in GiB, released by an Amazon File Cache AUTO_RELEASE_DATA task that automatically releases files from the cache.
-
#succeeded_count ⇒ Integer
A running total of the number of files that the task has successfully processed.
-
#total_count ⇒ Integer
The total number of files that the task will process.
Instance Attribute Details
#failed_count ⇒ Integer
A running total of the number of files that the task failed to process.
4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/aws-sdk-fsx/types.rb', line 4137 class DataRepositoryTaskStatus < Struct.new( :total_count, :succeeded_count, :failed_count, :last_updated_time, :released_capacity) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The time at which the task status was last updated.
4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/aws-sdk-fsx/types.rb', line 4137 class DataRepositoryTaskStatus < Struct.new( :total_count, :succeeded_count, :failed_count, :last_updated_time, :released_capacity) SENSITIVE = [] include Aws::Structure end |
#released_capacity ⇒ Integer
The total amount of data, in GiB, released by an Amazon File Cache AUTO_RELEASE_DATA task that automatically releases files from the cache.
4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/aws-sdk-fsx/types.rb', line 4137 class DataRepositoryTaskStatus < Struct.new( :total_count, :succeeded_count, :failed_count, :last_updated_time, :released_capacity) SENSITIVE = [] include Aws::Structure end |
#succeeded_count ⇒ Integer
A running total of the number of files that the task has successfully processed.
4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/aws-sdk-fsx/types.rb', line 4137 class DataRepositoryTaskStatus < Struct.new( :total_count, :succeeded_count, :failed_count, :last_updated_time, :released_capacity) SENSITIVE = [] include Aws::Structure end |
#total_count ⇒ Integer
The total number of files that the task will process. While a task is executing, the sum of SucceededCount plus FailedCount may not equal TotalCount. When the task is complete, TotalCount equals the sum of SucceededCount plus FailedCount.
4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/aws-sdk-fsx/types.rb', line 4137 class DataRepositoryTaskStatus < Struct.new( :total_count, :succeeded_count, :failed_count, :last_updated_time, :released_capacity) SENSITIVE = [] include Aws::Structure end |