Class: Aws::FSx::Types::DeleteFileSystemWindowsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DeleteFileSystemWindowsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
The configuration object for the Microsoft Windows file system used in the DeleteFileSystem operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#final_backup_tags ⇒ Array<Types::Tag>
A set of tags for your final backup.
-
#skip_final_backup ⇒ Boolean
By default, Amazon FSx for Windows takes a final backup on your behalf when the
DeleteFileSystemoperation is invoked.
Instance Attribute Details
#final_backup_tags ⇒ Array<Types::Tag>
A set of tags for your final backup.
4426 4427 4428 4429 4430 4431 |
# File 'lib/aws-sdk-fsx/types.rb', line 4426 class DeleteFileSystemWindowsConfiguration < Struct.new( :skip_final_backup, :final_backup_tags) SENSITIVE = [] include Aws::Structure end |
#skip_final_backup ⇒ Boolean
By default, Amazon FSx for Windows takes a final backup on your behalf when the DeleteFileSystem operation is invoked. Doing this helps protect you from data loss, and we highly recommend taking the final backup. If you want to skip this backup, use this flag to do so.
4426 4427 4428 4429 4430 4431 |
# File 'lib/aws-sdk-fsx/types.rb', line 4426 class DeleteFileSystemWindowsConfiguration < Struct.new( :skip_final_backup, :final_backup_tags) SENSITIVE = [] include Aws::Structure end |