Class: Aws::FSx::Types::DescribeBackupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DescribeBackupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
The request object for the DescribeBackups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_ids ⇒ Array<String>
The IDs of the backups that you want to retrieve.
-
#filters ⇒ Array<Types::Filter>
The filters structure.
-
#max_results ⇒ Integer
Maximum number of backups to return in the response.
-
#next_token ⇒ String
An opaque pagination token returned from a previous
DescribeBackupsoperation.
Instance Attribute Details
#backup_ids ⇒ Array<String>
The IDs of the backups that you want to retrieve. This parameter value overrides any filters. If any IDs aren’t found, a BackupNotFound error occurs.
4698 4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-fsx/types.rb', line 4698 class DescribeBackupsRequest < Struct.new( :backup_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
The filters structure. The supported names are file-system-id, backup-type, file-system-type, and volume-id.
4698 4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-fsx/types.rb', line 4698 class DescribeBackupsRequest < Struct.new( :backup_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of backups to return in the response. This parameter value must be greater than 0. The number of items that Amazon FSx returns is the minimum of the MaxResults parameter specified in the request and the service’s internal maximum number of items per page.
4698 4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-fsx/types.rb', line 4698 class DescribeBackupsRequest < Struct.new( :backup_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An opaque pagination token returned from a previous DescribeBackups operation. If a token is present, the operation continues the list from where the returning call left off.
4698 4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/aws-sdk-fsx/types.rb', line 4698 class DescribeBackupsRequest < Struct.new( :backup_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |