Class: Aws::FSx::Types::DescribeBackupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DescribeBackupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Response object for the DescribeBackups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backups ⇒ Array<Types::Backup>
An array of backups.
-
#next_token ⇒ String
A
NextTokenvalue is present if there are more backups than returned in the response.
Instance Attribute Details
#backups ⇒ Array<Types::Backup>
An array of backups.
4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-fsx/types.rb', line 4786 class DescribeBackupsResponse < Struct.new( :backups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A NextToken value is present if there are more backups than returned in the response. You can use the NextToken value in the subsequent request to fetch the backups.
4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-fsx/types.rb', line 4786 class DescribeBackupsResponse < Struct.new( :backups, :next_token) SENSITIVE = [] include Aws::Structure end |