Class: Aws::FSx::Types::DescribeDataRepositoryAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DescribeDataRepositoryAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_ids ⇒ Array<String>
IDs of the data repository associations whose descriptions you want to retrieve (String).
-
#filters ⇒ Array<Types::Filter>
A list of
Filterelements. -
#max_results ⇒ Integer
The maximum number of resources to return in the response.
-
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String).
Instance Attribute Details
#association_ids ⇒ Array<String>
IDs of the data repository associations whose descriptions you want to retrieve (String).
4816 4817 4818 4819 4820 4821 4822 4823 |
# File 'lib/aws-sdk-fsx/types.rb', line 4816 class DescribeDataRepositoryAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A list of Filter elements.
4816 4817 4818 4819 4820 4821 4822 4823 |
# File 'lib/aws-sdk-fsx/types.rb', line 4816 class DescribeDataRepositoryAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resources to return in the response. This value must be an integer greater than zero.
4816 4817 4818 4819 4820 4821 4822 4823 |
# File 'lib/aws-sdk-fsx/types.rb', line 4816 class DescribeDataRepositoryAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.
4816 4817 4818 4819 4820 4821 4822 4823 |
# File 'lib/aws-sdk-fsx/types.rb', line 4816 class DescribeDataRepositoryAssociationsRequest < Struct.new( :association_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |