Class: Aws::FSx::Types::DescribeDataRepositoryTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DescribeDataRepositoryTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::DataRepositoryTaskFilter>
(Optional) You can use filters to narrow the
DescribeDataRepositoryTasksresponse to include just tasks for specific file systems, or tasks in a specific lifecycle state. -
#max_results ⇒ Integer
The maximum number of resources to return in the response.
-
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String).
-
#task_ids ⇒ Array<String>
(Optional) IDs of the tasks whose descriptions you want to retrieve (String).
Instance Attribute Details
#filters ⇒ Array<Types::DataRepositoryTaskFilter>
(Optional) You can use filters to narrow the DescribeDataRepositoryTasks response to include just tasks for specific file systems, or tasks in a specific lifecycle state.
4870 4871 4872 4873 4874 4875 4876 4877 |
# File 'lib/aws-sdk-fsx/types.rb', line 4870 class DescribeDataRepositoryTasksRequest < Struct.new( :task_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resources to return in the response. This value must be an integer greater than zero.
4870 4871 4872 4873 4874 4875 4876 4877 |
# File 'lib/aws-sdk-fsx/types.rb', line 4870 class DescribeDataRepositoryTasksRequest < Struct.new( :task_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.
4870 4871 4872 4873 4874 4875 4876 4877 |
# File 'lib/aws-sdk-fsx/types.rb', line 4870 class DescribeDataRepositoryTasksRequest < Struct.new( :task_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#task_ids ⇒ Array<String>
(Optional) IDs of the tasks whose descriptions you want to retrieve (String).
4870 4871 4872 4873 4874 4875 4876 4877 |
# File 'lib/aws-sdk-fsx/types.rb', line 4870 class DescribeDataRepositoryTasksRequest < Struct.new( :task_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |