Class: Aws::FSx::Types::DescribeFileCachesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_cache_idsArray<String>

IDs of the caches whose descriptions you want to retrieve (String).



5197
5198
5199
5200
5201
5202
5203
# File 'lib/aws-sdk-fsx/types.rb', line 5197

class DescribeFileCachesRequest < Struct.new(
  :file_cache_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of resources to return in the response. This value must be an integer greater than zero.



5197
5198
5199
5200
5201
5202
5203
# File 'lib/aws-sdk-fsx/types.rb', line 5197

class DescribeFileCachesRequest < Struct.new(
  :file_cache_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.



5197
5198
5199
5200
5201
5202
5203
# File 'lib/aws-sdk-fsx/types.rb', line 5197

class DescribeFileCachesRequest < Struct.new(
  :file_cache_ids,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end