Class: Aws::FSx::Types::DescribeS3AccessPointAttachmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::S3AccessPointAttachmentsFilter>

Enter a filter Name and Values pair to view a select set of S3 access point attachments.



5366
5367
5368
5369
5370
5371
5372
5373
# File 'lib/aws-sdk-fsx/types.rb', line 5366

class DescribeS3AccessPointAttachmentsRequest < Struct.new(
  :names,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of resources to return in the response. This value must be an integer greater than zero.



5366
5367
5368
5369
5370
5371
5372
5373
# File 'lib/aws-sdk-fsx/types.rb', line 5366

class DescribeS3AccessPointAttachmentsRequest < Struct.new(
  :names,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#namesArray<String>

The names of the S3 access point attachments whose descriptions you want to retrieve.



5366
5367
5368
5369
5370
5371
5372
5373
# File 'lib/aws-sdk-fsx/types.rb', line 5366

class DescribeS3AccessPointAttachmentsRequest < Struct.new(
  :names,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.



5366
5367
5368
5369
5370
5371
5372
5373
# File 'lib/aws-sdk-fsx/types.rb', line 5366

class DescribeS3AccessPointAttachmentsRequest < Struct.new(
  :names,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end