Class: Aws::FSx::Types::DescribeStorageVirtualMachinesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DescribeStorageVirtualMachinesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::StorageVirtualMachineFilter>
Enter a filter name:value pair to view a select set of SVMs.
-
#max_results ⇒ Integer
The maximum number of resources to return in the response.
-
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String).
-
#storage_virtual_machine_ids ⇒ Array<String>
Enter the ID of one or more SVMs that you want to view.
Instance Attribute Details
#filters ⇒ Array<Types::StorageVirtualMachineFilter>
Enter a filter name:value pair to view a select set of SVMs.
5165 5166 5167 5168 5169 5170 5171 5172 |
# File 'lib/aws-sdk-fsx/types.rb', line 5165 class DescribeStorageVirtualMachinesRequest < Struct.new( :storage_virtual_machine_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resources to return in the response. This value must be an integer greater than zero.
5165 5166 5167 5168 5169 5170 5171 5172 |
# File 'lib/aws-sdk-fsx/types.rb', line 5165 class DescribeStorageVirtualMachinesRequest < Struct.new( :storage_virtual_machine_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.
5165 5166 5167 5168 5169 5170 5171 5172 |
# File 'lib/aws-sdk-fsx/types.rb', line 5165 class DescribeStorageVirtualMachinesRequest < Struct.new( :storage_virtual_machine_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#storage_virtual_machine_ids ⇒ Array<String>
Enter the ID of one or more SVMs that you want to view.
5165 5166 5167 5168 5169 5170 5171 5172 |
# File 'lib/aws-sdk-fsx/types.rb', line 5165 class DescribeStorageVirtualMachinesRequest < Struct.new( :storage_virtual_machine_ids, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |