Class: Aws::FSx::Types::FileCacheLustreConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

The configuration for the Amazon File Cache resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_typeString

The deployment type of the Amazon File Cache resource, which must be CACHE_1.

Returns:



6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/aws-sdk-fsx/types.rb', line 6148

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#log_configurationTypes::LustreLogConfiguration

The configuration for Lustre logging used to write the enabled logging events for your Amazon File Cache resource to Amazon CloudWatch Logs.

Returns:



6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/aws-sdk-fsx/types.rb', line 6148

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_configurationTypes::FileCacheLustreMetadataConfiguration

The configuration for a Lustre MDT (Metadata Target) storage volume.

Returns:



6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/aws-sdk-fsx/types.rb', line 6148

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#mount_nameString

You use the MountName value when mounting the cache. If you pass a cache ID to the DescribeFileCaches operation, it returns the the MountName value as part of the cache’s description.

Returns:



6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/aws-sdk-fsx/types.rb', line 6148

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#per_unit_storage_throughputInteger

Per unit storage throughput represents the megabytes per second of read or write throughput per 1 tebibyte of storage provisioned. Cache throughput capacity is equal to Storage capacity (TiB) * PerUnitStorageThroughput (MB/s/TiB). The only supported value is 1000.

Returns:



6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/aws-sdk-fsx/types.rb', line 6148

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_start_timeString

The preferred start time to perform weekly maintenance, formatted d:HH:MM in the UTC time zone, where d is the weekday number, from 1 through 7, beginning with Monday and ending with Sunday.

For example, 1:05:00 specifies maintenance at 5 AM Monday.

Returns:



6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/aws-sdk-fsx/types.rb', line 6148

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end