Class: Aws::FSx::Types::FileSystemLustreMetadataConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::FileSystemLustreMetadataConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
The Lustre metadata performance configuration of an Amazon FSx for Lustre file system using a PERSISTENT_2 deployment type. The configuration enables the file system to support increasing metadata performance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iops ⇒ Integer
The number of Metadata IOPS provisioned for the file system.
-
#mode ⇒ String
The metadata configuration mode for provisioning Metadata IOPS for the file system.
Instance Attribute Details
#iops ⇒ Integer
The number of Metadata IOPS provisioned for the file system. Valid values are 1500, 3000, 6000, 12000, and multiples of 12000 up to a maximum of 192000.
6174 6175 6176 6177 6178 6179 |
# File 'lib/aws-sdk-fsx/types.rb', line 6174 class FileSystemLustreMetadataConfiguration < Struct.new( :iops, :mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The metadata configuration mode for provisioning Metadata IOPS for the file system.
-
In AUTOMATIC mode, FSx for Lustre automatically provisions and scales the number of Metadata IOPS on your file system based on your file system storage capacity.
-
In USER_PROVISIONED mode, you can choose to specify the number of Metadata IOPS to provision for your file system.
6174 6175 6176 6177 6178 6179 |
# File 'lib/aws-sdk-fsx/types.rb', line 6174 class FileSystemLustreMetadataConfiguration < Struct.new( :iops, :mode) SENSITIVE = [] include Aws::Structure end |