Class: Aws::FSx::Types::NFSDataRepositoryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::NFSDataRepositoryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
The configuration for a data repository association that links an Amazon File Cache resource to an NFS data repository.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_export_policy ⇒ Types::AutoExportPolicy
This parameter is not supported for Amazon File Cache.
-
#dns_ips ⇒ Array<String>
A list of up to 2 IP addresses of DNS servers used to resolve the NFS file system domain name.
-
#version ⇒ String
The version of the NFS (Network File System) protocol of the NFS data repository.
Instance Attribute Details
#auto_export_policy ⇒ Types::AutoExportPolicy
This parameter is not supported for Amazon File Cache.
6785 6786 6787 6788 6789 6790 6791 |
# File 'lib/aws-sdk-fsx/types.rb', line 6785 class NFSDataRepositoryConfiguration < Struct.new( :version, :dns_ips, :auto_export_policy) SENSITIVE = [] include Aws::Structure end |
#dns_ips ⇒ Array<String>
A list of up to 2 IP addresses of DNS servers used to resolve the NFS file system domain name. The provided IP addresses can either be the IP addresses of a DNS forwarder or resolver that the customer manages and runs inside the customer VPC, or the IP addresses of the on-premises DNS servers.
6785 6786 6787 6788 6789 6790 6791 |
# File 'lib/aws-sdk-fsx/types.rb', line 6785 class NFSDataRepositoryConfiguration < Struct.new( :version, :dns_ips, :auto_export_policy) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the NFS (Network File System) protocol of the NFS data repository. Currently, the only supported value is NFS3, which indicates that the data repository must support the NFSv3 protocol.
6785 6786 6787 6788 6789 6790 6791 |
# File 'lib/aws-sdk-fsx/types.rb', line 6785 class NFSDataRepositoryConfiguration < Struct.new( :version, :dns_ips, :auto_export_policy) SENSITIVE = [] include Aws::Structure end |