Class: Aws::FSx::Types::RestoreVolumeFromSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



7683
7684
7685
7686
7687
7688
7689
7690
# File 'lib/aws-sdk-fsx/types.rb', line 7683

class RestoreVolumeFromSnapshotRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :snapshot_id,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#optionsArray<String>

The settings used when restoring the specified volume from snapshot.

  • DELETE_INTERMEDIATE_SNAPSHOTS - Deletes snapshots between the current state and the specified snapshot. If there are intermediate snapshots and this option isn’t used, RestoreVolumeFromSnapshot fails.

  • DELETE_CLONED_VOLUMES - Deletes any dependent clone volumes created from intermediate snapshots. If there are any dependent clone volumes and this option isn’t used, RestoreVolumeFromSnapshot fails.



7683
7684
7685
7686
7687
7688
7689
7690
# File 'lib/aws-sdk-fsx/types.rb', line 7683

class RestoreVolumeFromSnapshotRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :snapshot_id,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_idString

The ID of the source snapshot. Specifies the snapshot that you are restoring from.



7683
7684
7685
7686
7687
7688
7689
7690
# File 'lib/aws-sdk-fsx/types.rb', line 7683

class RestoreVolumeFromSnapshotRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :snapshot_id,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume that you are restoring.



7683
7684
7685
7686
7687
7688
7689
7690
# File 'lib/aws-sdk-fsx/types.rb', line 7683

class RestoreVolumeFromSnapshotRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :snapshot_id,
  :options)
  SENSITIVE = []
  include Aws::Structure
end