Class: Aws::FSx::Types::SelfManagedActiveDirectoryConfigurationUpdates
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::SelfManagedActiveDirectoryConfigurationUpdates
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Specifies changes you are making to the self-managed Microsoft Active Directory configuration to which an FSx for Windows File Server file system or an FSx for ONTAP SVM is joined.
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#dns_ips ⇒ Array<String>
A list of up to three DNS server or domain controller IP addresses in your self-managed Active Directory domain.
-
#domain_name ⇒ String
Specifies an updated fully qualified domain name of your self-managed Active Directory configuration.
-
#file_system_administrators_group ⇒ String
For FSx for ONTAP file systems only - Specifies the updated name of the self-managed Active Directory domain group whose members are granted administrative privileges for the Amazon FSx resource.
-
#organizational_unit_distinguished_name ⇒ String
Specifies an updated fully qualified distinguished name of the organization unit within your self-managed Active Directory.
-
#password ⇒ String
Specifies the updated password for the service account on your self-managed Active Directory domain.
-
#user_name ⇒ String
Specifies the updated user name for the service account on your self-managed Active Directory domain.
Instance Attribute Details
#dns_ips ⇒ Array<String>
A list of up to three DNS server or domain controller IP addresses in your self-managed Active Directory domain.
8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 |
# File 'lib/aws-sdk-fsx/types.rb', line 8061 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#domain_name ⇒ String
Specifies an updated fully qualified domain name of your self-managed Active Directory configuration.
8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 |
# File 'lib/aws-sdk-fsx/types.rb', line 8061 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#file_system_administrators_group ⇒ String
For FSx for ONTAP file systems only - Specifies the updated name of the self-managed Active Directory domain group whose members are granted administrative privileges for the Amazon FSx resource.
8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 |
# File 'lib/aws-sdk-fsx/types.rb', line 8061 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#organizational_unit_distinguished_name ⇒ String
Specifies an updated fully qualified distinguished name of the organization unit within your self-managed Active Directory.
8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 |
# File 'lib/aws-sdk-fsx/types.rb', line 8061 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Specifies the updated password for the service account on your self-managed Active Directory domain. Amazon FSx uses this account to join to your self-managed Active Directory domain.
8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 |
# File 'lib/aws-sdk-fsx/types.rb', line 8061 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#user_name ⇒ String
Specifies the updated user name for the service account on your self-managed Active Directory domain. Amazon FSx uses this account to join to your self-managed Active Directory domain.
This account must have the permissions required to join computers to the domain in the organizational unit provided in OrganizationalUnitDistinguishedName.
8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 |
# File 'lib/aws-sdk-fsx/types.rb', line 8061 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |