Class: Aws::FSx::Types::UpdateFileCacheLustreConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::UpdateFileCacheLustreConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
The configuration update for an Amazon File Cache resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#weekly_maintenance_start_time ⇒ String
A recurring weekly time, in the format
D:HH:MM.
Instance Attribute Details
#weekly_maintenance_start_time ⇒ String
A recurring weekly time, in the format D:HH:MM.
D is the day of the week, for which 1 represents Monday and 7 represents Sunday. For further details, see [the ISO-8601 spec as described on Wikipedia].
HH is the zero-padded hour of the day (0-23), and MM is the zero-padded minute of the hour.
For example, 1:05:00 specifies maintenance at 5 AM Monday.
8737 8738 8739 8740 8741 |
# File 'lib/aws-sdk-fsx/types.rb', line 8737 class UpdateFileCacheLustreConfiguration < Struct.new( :weekly_maintenance_start_time) SENSITIVE = [] include Aws::Structure end |