Class: Aws::FSx::Types::UpdateFileSystemLustreMetadataConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::UpdateFileSystemLustreMetadataConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
The Lustre metadata performance configuration update for an Amazon FSx for Lustre file system using a PERSISTENT_2 deployment type. You can request an increase in your file system’s Metadata IOPS and/or switch your file system’s metadata configuration mode. For more information, see [Managing metadata performance] in the *Amazon FSx for Lustre User Guide*.
[1]: docs.aws.amazon.com/fsx/latest/LustreGuide/managing-metadata-performance.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iops ⇒ Integer
(USER_PROVISIONED mode only) Specifies the number of Metadata IOPS to provision for your file system.
-
#mode ⇒ String
The metadata configuration mode for provisioning Metadata IOPS for an FSx for Lustre file system using a
PERSISTENT_2deployment type.
Instance Attribute Details
#iops ⇒ Integer
(USER_PROVISIONED mode only) Specifies the number of Metadata IOPS to provision for your file system. Valid values are 1500, 3000, 6000, 12000, and multiples of 12000 up to a maximum of 192000.
The value you provide must be greater than or equal to the current number of Metadata IOPS provisioned for the file system.
9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-fsx/types.rb', line 9056 class UpdateFileSystemLustreMetadataConfiguration < Struct.new( :iops, :mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The metadata configuration mode for provisioning Metadata IOPS for an FSx for Lustre file system using a PERSISTENT_2 deployment type.
-
To increase the Metadata IOPS or to switch from AUTOMATIC mode, specify
USER_PROVISIONEDas the value for this parameter. Then use the Iops parameter to provide a Metadata IOPS value that is greater than or equal to the current number of Metadata IOPS provisioned for the file system. -
To switch from USER_PROVISIONED mode, specify
AUTOMATICas the value for this parameter, but do not input a value for Iops.<note markdown=“1”> If you request to switch from USER_PROVISIONED to AUTOMATIC mode and the current Metadata IOPS value is greater than the automated default, FSx for Lustre rejects the request because downscaling Metadata IOPS is not supported.
</note>
9056 9057 9058 9059 9060 9061 |
# File 'lib/aws-sdk-fsx/types.rb', line 9056 class UpdateFileSystemLustreMetadataConfiguration < Struct.new( :iops, :mode) SENSITIVE = [] include Aws::Structure end |