Class: Aws::FSx::Types::UpdateVolumeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

(Optional) An idempotency token for resource creation, in a string of up to 63 ASCII characters. This token is automatically filled on your behalf when you use the Command Line Interface (CLI) or an Amazon Web Services SDK.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


9919
9920
9921
9922
9923
9924
9925
9926
9927
# File 'lib/aws-sdk-fsx/types.rb', line 9919

class UpdateVolumeRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :ontap_configuration,
  :name,
  :open_zfs_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the OpenZFS volume. OpenZFS root volumes are automatically named FSX. Child volume names must be unique among their parent volume’s children. The name of the volume is part of the mount string for the OpenZFS volume.

Returns:

  • (String)


9919
9920
9921
9922
9923
9924
9925
9926
9927
# File 'lib/aws-sdk-fsx/types.rb', line 9919

class UpdateVolumeRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :ontap_configuration,
  :name,
  :open_zfs_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ontap_configurationTypes::UpdateOntapVolumeConfiguration

The configuration of the ONTAP volume that you are updating.



9919
9920
9921
9922
9923
9924
9925
9926
9927
# File 'lib/aws-sdk-fsx/types.rb', line 9919

class UpdateVolumeRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :ontap_configuration,
  :name,
  :open_zfs_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#open_zfs_configurationTypes::UpdateOpenZFSVolumeConfiguration

The configuration of the OpenZFS volume that you are updating.



9919
9920
9921
9922
9923
9924
9925
9926
9927
# File 'lib/aws-sdk-fsx/types.rb', line 9919

class UpdateVolumeRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :ontap_configuration,
  :name,
  :open_zfs_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The ID of the volume that you want to update, in the format fsvol-0123456789abcdef0.

Returns:

  • (String)


9919
9920
9921
9922
9923
9924
9925
9926
9927
# File 'lib/aws-sdk-fsx/types.rb', line 9919

class UpdateVolumeRequest < Struct.new(
  :client_request_token,
  :volume_id,
  :ontap_configuration,
  :name,
  :open_zfs_configuration)
  SENSITIVE = []
  include Aws::Structure
end