Class: Aws::FSx::Types::DescribeFileCachesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::DescribeFileCachesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_cache_ids ⇒ Array<String>
IDs of the caches whose descriptions you want to retrieve (String).
-
#max_results ⇒ Integer
The maximum number of resources to return in the response.
-
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String).
Instance Attribute Details
#file_cache_ids ⇒ Array<String>
IDs of the caches whose descriptions you want to retrieve (String).
4917 4918 4919 4920 4921 4922 4923 |
# File 'lib/aws-sdk-fsx/types.rb', line 4917 class DescribeFileCachesRequest < Struct.new( :file_cache_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resources to return in the response. This value must be an integer greater than zero.
4917 4918 4919 4920 4921 4922 4923 |
# File 'lib/aws-sdk-fsx/types.rb', line 4917 class DescribeFileCachesRequest < Struct.new( :file_cache_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Optional) Opaque pagination token returned from a previous operation (String). If present, this token indicates from what point you can continue processing the request, where the previous NextToken value left off.
4917 4918 4919 4920 4921 4922 4923 |
# File 'lib/aws-sdk-fsx/types.rb', line 4917 class DescribeFileCachesRequest < Struct.new( :file_cache_ids, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |