Class: Aws::FSx::Types::FileCacheLustreConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-fsx/types.rb

Overview

The configuration for the Amazon File Cache resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_typeString

The deployment type of the Amazon File Cache resource, which must be CACHE_1.

Returns:



5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/aws-sdk-fsx/types.rb', line 5783

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#log_configurationTypes::LustreLogConfiguration

The configuration for Lustre logging used to write the enabled logging events for your Amazon File Cache resource to Amazon CloudWatch Logs.

Returns:



5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/aws-sdk-fsx/types.rb', line 5783

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_configurationTypes::FileCacheLustreMetadataConfiguration

The configuration for a Lustre MDT (Metadata Target) storage volume.

Returns:



5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/aws-sdk-fsx/types.rb', line 5783

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#mount_nameString

You use the MountName value when mounting the cache. If you pass a cache ID to the DescribeFileCaches operation, it returns the the MountName value as part of the cache’s description.

Returns:



5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/aws-sdk-fsx/types.rb', line 5783

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#per_unit_storage_throughputInteger

Per unit storage throughput represents the megabytes per second of read or write throughput per 1 tebibyte of storage provisioned. Cache throughput capacity is equal to Storage capacity (TiB) * PerUnitStorageThroughput (MB/s/TiB). The only supported value is 1000.

Returns:



5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/aws-sdk-fsx/types.rb', line 5783

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#weekly_maintenance_start_timeString

A recurring weekly time, in the format D:HH:MM.

D is the day of the week, for which 1 represents Monday and 7 represents Sunday. For further details, see [the ISO-8601 spec as described on Wikipedia].

HH is the zero-padded hour of the day (0-23), and MM is the zero-padded minute of the hour.

For example, 1:05:00 specifies maintenance at 5 AM Monday.

[1]: en.wikipedia.org/wiki/ISO_week_date

Returns:



5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/aws-sdk-fsx/types.rb', line 5783

class FileCacheLustreConfiguration < Struct.new(
  :per_unit_storage_throughput,
  :deployment_type,
  :mount_name,
  :weekly_maintenance_start_time,
  :metadata_configuration,
  :log_configuration)
  SENSITIVE = []
  include Aws::Structure
end