Class: Aws::FSx::Types::SelfManagedActiveDirectoryConfigurationUpdates
- Inherits:
-
Struct
- Object
- Struct
- Aws::FSx::Types::SelfManagedActiveDirectoryConfigurationUpdates
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fsx/types.rb
Overview
Specifies changes you are making to the self-managed Microsoft Active Directory (AD) configuration to which an FSx for Windows File Server file system or an FSx for ONTAP SVM is joined.
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#dns_ips ⇒ Array<String>
A list of up to three DNS server or domain controller IP addresses in your self-managed AD domain.
-
#domain_name ⇒ String
Specifies an updated fully qualified domain name of your self-managed AD configuration.
-
#file_system_administrators_group ⇒ String
Specifies the updated name of the self-managed AD domain group whose members are granted administrative privileges for the Amazon FSx resource.
-
#organizational_unit_distinguished_name ⇒ String
Specifies an updated fully qualified distinguished name of the organization unit within your self-managed AD.
-
#password ⇒ String
Specifies the updated password for the service account on your self-managed AD domain.
-
#user_name ⇒ String
Specifies the updated user name for the service account on your self-managed AD domain.
Instance Attribute Details
#dns_ips ⇒ Array<String>
A list of up to three DNS server or domain controller IP addresses in your self-managed AD domain.
7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 |
# File 'lib/aws-sdk-fsx/types.rb', line 7958 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#domain_name ⇒ String
Specifies an updated fully qualified domain name of your self-managed AD configuration.
7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 |
# File 'lib/aws-sdk-fsx/types.rb', line 7958 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#file_system_administrators_group ⇒ String
Specifies the updated name of the self-managed AD domain group whose members are granted administrative privileges for the Amazon FSx resource.
7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 |
# File 'lib/aws-sdk-fsx/types.rb', line 7958 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#organizational_unit_distinguished_name ⇒ String
Specifies an updated fully qualified distinguished name of the organization unit within your self-managed AD.
7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 |
# File 'lib/aws-sdk-fsx/types.rb', line 7958 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Specifies the updated password for the service account on your self-managed AD domain. Amazon FSx uses this account to join to your self-managed AD domain.
7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 |
# File 'lib/aws-sdk-fsx/types.rb', line 7958 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |
#user_name ⇒ String
Specifies the updated user name for the service account on your self-managed AD domain. Amazon FSx uses this account to join to your self-managed AD domain.
This account must have the permissions required to join computers to the domain in the organizational unit provided in OrganizationalUnitDistinguishedName.
7958 7959 7960 7961 7962 7963 7964 7965 7966 7967 |
# File 'lib/aws-sdk-fsx/types.rb', line 7958 class SelfManagedActiveDirectoryConfigurationUpdates < Struct.new( :user_name, :password, :dns_ips, :domain_name, :organizational_unit_distinguished_name, :file_system_administrators_group) SENSITIVE = [:password] include Aws::Structure end |